@@ -72,10 +72,12 @@ class Network(object):
 		try: info["ip"] = output.split(f"PING {ip} (")[1].split("):")[0]
 		except: info["ip"] = None
 		if "Request timeout for" in output:
-			response["up"] = False
-		else:
+			info["up"] = False
+		elif " bytes from " in output:
 			info["up"] = True
-			
+		else:
+			info["up"] = None
+
 		# success.
 		return r3sponse.success(f"Successfully pinged [{ip}].", info)
 
